==> libdombey-3.7.txz: usr/local/include/dombey.h <==
/*
 * Dombey Copyright (c) 2010-2014 James Bailie.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *     * The name of James Bailie may not be used to endorse or promote 
 * products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
*/

char *scgi_get_env( char * );
char **scgi_get_envs();

char *scgi_get_param( char * );
char **scgi_get_params();

char *scgi_get_cookie( char * );
char **scgi_get_cookies();

char **scgi_get_file( char * );
char **scgi_get_files();
char **scgi_get_next_file( char **, char * );

void scgi_periodic( void (*)(), int );

void scgi_set_key_iv( char *, char * );
void scgi_set_name( char * );

char *scgi_read_enc( int, int * );

void scgi_init_func();
void scgi_child_init_func();

void scgi_request_handler();
char *scgi_form_encode( char * );

extern char *scgi_config_file;

==> libdombey-5.29.txz: usr/local/include/dombey.h <==
/*
 * Dombey Copyright (c) 2010-2015 James Bailie.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *     * The name of James Bailie may not be used to endorse or promote 
 * products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
*/

char *scgi_get_env( char * );
char **scgi_get_envs();

char *scgi_get_param( char * );
char **scgi_get_params();

char *scgi_get_cookie( char * );
char **scgi_get_cookies();

char **scgi_get_file( char * );
char **scgi_get_files();
char **scgi_get_next_file( char **, char * );

void scgi_set_periodic( void (*)(), int );
void scgi_encrypt_files( int );
void scgi_set_name( char * );

char *scgi_read_encrypted( int, int *, char *, char * );

void scgi_init_func();
void scgi_worker_init_func();

void scgi_request_handler( FILE * );

char *scgi_form_encode( char * );
char *scgi_html_escape( char * );

void scgi_thread_exit();

extern char *scgi_config_file, *scgi_root_dir, *scgi_interface,
            *scgi_port, *scgi_user, *scgi_group;
